@@ -7,6 +7,7 @@ from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 from django.shortcuts import redirect
 from django.contrib.sites.models import Site
+from django.utils.translation import activate
 import models as mymodels
 import forms as myforms
 
@@ -15,6 +16,22 @@ from django.conf import settings as conf
 from django.views.generic import DetailView
 from wkhtmltopdf.views import PDFTemplateView
 
+def changelang(request, code):
+    from django.utils.translation import check_for_language, activate, to_locale, get_language
+    next = request.REQUEST.get('next', None)
+    if not next:
+        next = request.META.get('HTTP_REFERER', None)
+    if not next:
+        next = '/'
+    response = HttpResponseRedirect(next)
+    lang_code = code
+    if lang_code and check_for_language(lang_code):
+        if hasattr(request, 'session'):
+            request.session['django_language'] = lang_code
+        else:
+            response.set_cookie(settings.LANGUAGE_COOKIE_NAME, lang_code)
+    return response
+
 
 class PDFInvoiceDetailView(PDFTemplateView):
 
@@ -43,6 +60,7 @@ class InvoiceDetailView(DetailView):
         pass
 
     def get_object(self):
+        changelang(self.request, self.kwargs['lang'])
         myinvoice = get_object_or_404(mymodels.Invoice, id=self.kwargs['id'])
         return myinvoice
 
